#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const express_1 = __importDefault(require("express"));
const fs_1 = __importDefault(require("fs"));
const http_1 = __importDefault(require("http"));
const https_1 = __importDefault(require("https"));
const ini_1 = __importDefault(require("ini"));
const multer_1 = __importDefault(require("multer"));
const nunjucks_1 = __importDefault(require("nunjucks"));
const path_1 = __importDefault(require("path"));
const auth_1 = require("./auth");
const config_1 = require("./config");
const process_interface_1 = require("./process_interface");
const utils_1 = require("./utils");
const wpa_supplicant_config_1 = require("./wpa_supplicant_config");
const app = (0, express_1.default)();
app.use((0, auth_1.pam_auth)("Admin Area"));
const multipart = (0, multer_1.default)({ dest: "/tmp/" });
const content_path = path_1.default.join(__dirname, "..", config_1.config.NODE_ENV === "development" ? "src" : "app", "content");
const nunjucks_configuration = {
    autoescape: true,
    noCache: config_1.config.NODE_ENV === "development",
};
nunjucks_1.default.configure(content_path + "/templates", {
    ...nunjucks_configuration,
    express: app,
});
const languages = ["en"];
const renderPage = (0, utils_1.renderPageInit)(content_path, config_1.config.DEFAULT_LANGUAGE);
const router = express_1.default.Router();
// Firmware Upload
const firmwareFuns = (0, process_interface_1.createProcessInterface)(router, "/upload_firmware_show");
router.post("/upload_firmware", multipart.single("file"), async (req, res) => {
    if (!req.authorized)
        return;
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const command = `rauc install ${req.file.path} && reboot`;
    firmwareFuns.setProcess((0, child_process_1.spawn)(command, { shell: true }));
    await renderPage(req.path, req.language, res, {
        authorized: req.authorized,
    });
});
// Manual Control
/*createProcessInterface(router, '/manual_control', () => {
  return spawn('manual_control', {shell: true});
});*/
// Network Configuration
router.all("/network", multipart.none(), async (req, res) => {
    let network_settings = ini_1.default.parse(fs_1.default
        .readFileSync(config_1.config.NETWORK_CONFIG_FILE, "utf-8")
        .replace(/Address=/g, "Address[]=")
        .replace(/DNS=/g, "DNS[]="));
    if (req.body) {
        network_settings = {
            ...network_settings,
            Network: {
                ...network_settings.Network,
                DHCP: req.body.dhcp ? "yes" : "no",
                Address: req.body.address.split(";"),
                Gateway: req.body.gateway,
                DNS: req.body.dns.split(";"),
            },
            Address: {
                Address: "169.254.79.79/16",
            },
        };
        fs_1.default.writeFileSync(config_1.config.NETWORK_CONFIG_FILE, ini_1.default
            .stringify(network_settings)
            .replace(/\[\]/g, "")
            .replace(/^.*=\n/gm, ""));
        if (config_1.config.NODE_ENV !== "development")
            (0, child_process_1.spawnSync)("systemctl restart systemd-networkd.service", { shell: true });
    }
    await renderPage(req.path, req.language, res, {
        dhcp: network_settings.Network.DHCP == "yes",
        address: network_settings.Network.Address
            ? network_settings.Network.Address.join(";")
            : "",
        gateway: network_settings.Network.Gateway,
        dns: network_settings.Network.DNS
            ? network_settings.Network.DNS.join(";")
            : "",
        authorized: req.authorized,
    });
});
const scan_result_regex = /^\w\w(?::\w\w)+[\t ]+[^\s]+[\t ]+[^\s]+[\t ]+([^\s]+)[\t ]+(.*?)$/gm;
const security_key_mgmt_map = new Map([
    ["none", "NONE"],
    ["personal", "WPA-PSK"],
    ["enterprise", "WPA-EAP"],
]);
const key_mgmt_security_map = new Map([
    ["NONE", "none"],
    ["WPA-PSK", "personal"],
    ["WPA-EAP", "enterprise"],
]);
router.all("/wireless", multipart.none(), async (req, res) => {
    let network_settings = ini_1.default.parse(fs_1.default
        .readFileSync(config_1.config.WIRELESS_NETWORK_CONFIG_FILE, "utf-8")
        .replace(/Address=/g, "Address[]=")
        .replace(/DNS=/g, "DNS[]="));
    const wpaConfig = new wpa_supplicant_config_1.WpaSupplicantConfig();
    const scan_string = (0, child_process_1.spawnSync)("wpa_cli scan > /dev/null && wpa_cli scan_results", { shell: true }).stdout.toString();
    const scan_result = [];
    let m;
    while ((m = scan_result_regex.exec(scan_string)) !== null) {
        scan_result.push({ flags: m[1], ssid: m[2] });
    }
    if (req.body) {
        network_settings = {
            ...network_settings,
            Network: {
                ...network_settings.Network,
                DHCP: req.body.dhcp ? "yes" : "no",
                Address: req.body.address.split(";"),
                Gateway: req.body.gateway,
                DNS: req.body.dns.split(";"),
            },
        };
        console.log(req.body);
        wpaConfig.network = {
            ssid: req.body[req.body.security + "_ssid"],
            eap: req.body[req.body.security + "_eap"],
            phase2: req.body[req.body.security + "_phase2"],
            identity: req.body[req.body.security + "_identity"],
            anonymous_identity: req.body[req.body.security + "_anonymous_identity"],
            password: req.body.security == "enterprise"
                ? req.body[req.body.security + "_password"]
                : undefined,
            psk: req.body.security != "enterprise"
                ? req.body[req.body.security + "_password"]
                : undefined,
            key_mgmt: security_key_mgmt_map.get(req.body.security),
        };
        fs_1.default.writeFileSync(config_1.config.WIRELESS_NETWORK_CONFIG_FILE, ini_1.default
            .stringify(network_settings)
            .replace(/\[\]/g, "")
            .replace(/^.*=\n/gm, ""));
        wpaConfig.write();
        if (config_1.config.NODE_ENV !== "development") {
            (0, child_process_1.spawnSync)("wpa_cli reconfigure; systemctl restart systemd-networkd.service", { shell: true });
        }
    }
    await renderPage(req.path, req.language, res, {
        scanned_networks: scan_result,
        ssid: wpaConfig.network.ssid,
        eap: wpaConfig.network.eap,
        phase2: wpaConfig.network.phase2,
        identity: wpaConfig.network.identity,
        anonymous_identity: wpaConfig.network.anonymous_identity,
        password: wpaConfig.network.password ?? wpaConfig.network.psk,
        dhcp: network_settings.Network.DHCP == "yes",
        address: network_settings.Network.Address
            ? network_settings.Network.Address.join(";")
            : "",
        gateway: network_settings.Network.Gateway,
        dns: network_settings.Network.DNS
            ? network_settings.Network.DNS.join(";")
            : "",
        authorized: req.authorized,
        security: key_mgmt_security_map.get(wpaConfig.network.key_mgmt ?? ""),
    });
});
// Crosslab Setup
router.all("/crosslab", multipart.none(), async (req, res) => {
    if (!req.authorized)
        return;
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    let crosslab_settings = {};
    try {
        crosslab_settings = JSON.parse(fs_1.default.readFileSync(config_1.config.CROSSLAB_CONFIG_FILE, "utf-8"));
    }
    catch {
        /* empty */
    }
    if (req.body) {
        crosslab_settings = {
            ...crosslab_settings,
            deviceId: req.body.id,
            authToken: req.body.token,
            url: req.body.url,
        };
        fs_1.default.writeFileSync(config_1.config.CROSSLAB_CONFIG_FILE, JSON.stringify(crosslab_settings));
        (0, child_process_1.spawnSync)("systemctl restart goldi-crosslab.service", { shell: true });
    }
    await renderPage(req.path, req.language, res, {
        id: crosslab_settings.deviceId,
        token: crosslab_settings.authToken,
        url: crosslab_settings.url,
        authorized: req.authorized,
    });
});
// General Setup
router.use("/", async (req, res) => {
    await renderPage(req.path, req.language, res, { authorized: req.authorized });
});
// IMG paths
app.use("/img", express_1.default.static(path_1.default.join(content_path, "img")));
// CSS paths
if (config_1.config.NODE_ENV === "development") {
    // When developing, we dynamically transform the css files with postcss
    // eslint-disable-next-line @typescript-eslint/no-var-requires
    const { postcss_transform } = require("./debug_utils");
    app.use("/css", postcss_transform(path_1.default.join(content_path, "css")));
}
else {
    // For production, we use precompiled css files
    app.use("/css", express_1.default.static(path_1.default.join(content_path, "css")));
}
// HTML paths
for (const language of languages) {
    app.get("/" + language + "/", async (req, res) => {
        await renderPage("index", language, res, { authorized: req.authorized });
    });
    app.use("/" + language + "/", async (req, _res, next) => {
        req.language = language;
        next();
    }, router);
}
app.get("/", function (req, res) {
    const selected_language = req.acceptsLanguages(languages) || config_1.config.DEFAULT_LANGUAGE;
    res.redirect(307, "/" + selected_language + req.originalUrl);
});
if (config_1.config.NODE_ENV === "development") {
    // When developing, we start a browserSync server after listen
    // eslint-disable-next-line @typescript-eslint/no-var-requires
    const { start_browserSync } = require("./debug_utils");
    const server = https_1.default
        .createServer((0, utils_1.createSSLCertificate)("./"), app)
        .listen(() => start_browserSync(server.address().port));
}
else {
    // Just listen on the configured port
    https_1.default
        .createServer((0, utils_1.createSSLCertificate)("/data/certificates/"), app)
        .listen(config_1.config.PORT);
    http_1.default
        .createServer((_req, res) => {
        res.writeHead(302, { Location: "https://goldi1.local/" });
        res.end();
    })
        .listen(80);
}
//# sourceMappingURL=index.js.map