"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createProcessInterface = void 0;
function createProcessInterface(router, base, createProcess) {
    let pending_process = undefined;
    function prepareProcess(process) {
        pending_process = { process, stderr: { all: '' }, stdout: { all: '' } };
        function appendFun(stream) {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            return (data) => {
                stream.all += data.toString();
                console.log(data.toString());
            };
        }
        pending_process?.process.stdout.on('data', appendFun(pending_process.stdout));
        pending_process?.process.stderr.on('data', appendFun(pending_process.stderr));
        pending_process?.process.on('close', () => {
            pending_process = undefined;
        });
        // eslint-disable-next-line @typescript-eslint/no-empty-function
        pending_process?.process.stdin.on('error', () => { });
    }
    router.get(base + '/stream', (_req, res) => {
        res.writeHead(200, {
            'Content-Type': 'text/event-stream',
            'Cache-control': 'no-cache',
        });
        if (!pending_process) {
            if (!createProcess) {
                res.end();
                return;
            }
            prepareProcess(createProcess());
        }
        else {
            if (pending_process.stdout.all.length > 0)
                res.write('data: ' + JSON.stringify(pending_process.stdout.all) + '\n\n');
            if (pending_process.stderr.all.length > 0)
                res.write('stderr: ' + JSON.stringify(pending_process.stderr.all) + '\n\n');
        }
        pending_process?.process.stdout.on('data', data => {
            res.write('data: ' + JSON.stringify(data.toString()) + '\n\n');
        });
        pending_process?.process.stderr.on('data', data => {
            res.write('data: ' + JSON.stringify(data.toString()) + '\n\n');
        });
        pending_process?.process.on('close', function () {
            res.end();
        });
    });
    router.get(base + '/input', (req, res) => {
        if (!pending_process) {
            if (!createProcess) {
                res.sendStatus(404);
                return;
            }
            prepareProcess(createProcess());
        }
        try {
            const input = decodeURI(req.query.input);
            if (pending_process?.process.stdin.writable) {
                pending_process?.process.stdin.cork();
                pending_process?.process.stdin.write(input);
                pending_process?.process.stdin.uncork();
                res.sendStatus(204);
            }
        }
        catch (e) {
            res.sendStatus(500);
        }
    });
    return {
        setProcess: prepareProcess,
        isRunning: () => pending_process !== undefined,
    };
}
exports.createProcessInterface = createProcessInterface;
//# sourceMappingURL=process_interface.js.map