"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createSSLCertificate = exports.renderPageInit = exports.find_language_suffixed_files = exports.template_resolution = void 0;
const child_process_1 = require("child_process");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
function template_resolution(base_path, sub_path, default_language) {
    return async (filename, language) => {
        if (!language)
            language = default_language;
        filename = await find_language_suffixed_files(path_1.default.join(base_path, sub_path, filename), language, default_language, '.html');
        return path_1.default.relative(base_path, filename);
    };
}
exports.template_resolution = template_resolution;
async function find_language_suffixed_files(filename, language, default_language = 'en', overwrite_extension) {
    let ext_name = path_1.default.extname(filename);
    let basename = ext_name.length > 0 ? filename.slice(0, -ext_name.length) : filename;
    if (basename.endsWith('.'))
        basename = basename.slice(0, -1);
    if (overwrite_extension)
        ext_name = overwrite_extension;
    if (!ext_name.startsWith('.'))
        ext_name = '.' + ext_name;
    const possible_filenames = [basename + '_' + language + ext_name, basename + '_' + default_language + ext_name, basename + ext_name];
    for (const f of possible_filenames) {
        if (fs_1.default.existsSync(f)) {
            return f;
        }
    }
    throw new Error('Could not find file ' + filename);
}
exports.find_language_suffixed_files = find_language_suffixed_files;
function renderPageInit(content_path, default_language) {
    const page_resolution = template_resolution(content_path + '/templates', 'pages', default_language);
    return async function renderPage(page, language, res, vars = {}) {
        try {
            const page_template = await page_resolution(page, language);
            res.render(page_template, { ...vars, language });
        }
        catch (e) {
            const page_template = await page_resolution('404', language);
            res.render(page_template, { ...vars, language });
        }
    };
}
exports.renderPageInit = renderPageInit;
function createSSLCertificate(certificate_path) {
    fs_1.default.mkdirSync(certificate_path, { recursive: true });
    if (!fs_1.default.existsSync(certificate_path + 'key.pem')) {
        (0, child_process_1.execSync)('openssl genrsa -out ' + certificate_path + 'key.pem 2048');
    }
    if (!fs_1.default.existsSync(certificate_path + 'cert.pem')) {
        (0, child_process_1.execSync)('openssl req -x509 -sha256 -days 3650 -nodes \
                  -key ' +
            certificate_path +
            'key.pem -out ' +
            certificate_path +
            'cert.pem -subj "/CN=goldi.local" \
                  -addext "subjectAltName=DNS:goldi.local,IP:169.254.79.79"');
    }
    return {
        key: fs_1.default.readFileSync(certificate_path + 'key.pem'),
        cert: fs_1.default.readFileSync(certificate_path + 'cert.pem'),
    };
}
exports.createSSLCertificate = createSSLCertificate;
//# sourceMappingURL=utils.js.map